package com.bonus.material.scrap.service;

import java.util.List;
import com.bonus.material.scrap.domain.ScrapAuditorSet;

/**
 * 报废审核人员配置Service接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface IScrapAuditorSetService {
    /**
     * 查询报废审核人员配置
     * 
     * @param id 报废审核人员配置主键
     * @return 报废审核人员配置
     */
    public ScrapAuditorSet selectScrapAuditorSetById(Long id);

    /**
     * 查询报废审核人员配置列表
     * 
     * @param scrapAuditorSet 报废审核人员配置
     * @return 报废审核人员配置集合
     */
    public List<ScrapAuditorSet> selectScrapAuditorSetList(ScrapAuditorSet scrapAuditorSet);

    /**
     * 新增报废审核人员配置
     * 
     * @param scrapAuditorSet 报废审核人员配置
     * @return 结果
     */
    public int insertScrapAuditorSet(ScrapAuditorSet scrapAuditorSet);

    /**
     * 修改报废审核人员配置
     * 
     * @param scrapAuditorSet 报废审核人员配置
     * @return 结果
     */
    public int updateScrapAuditorSet(ScrapAuditorSet scrapAuditorSet);

    /**
     * 批量删除报废审核人员配置
     * 
     * @param ids 需要删除的报废审核人员配置主键集合
     * @return 结果
     */
    public int deleteScrapAuditorSetByIds(Long[] ids);

    /**
     * 删除报废审核人员配置信息
     * 
     * @param id 报废审核人员配置主键
     * @return 结果
     */
    public int deleteScrapAuditorSetById(Long id);
}
