package com.bonus.material.scrap.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.scrap.domain.ScrapAuditorSet;
import com.bonus.material.scrap.service.IScrapAuditorSetService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 报废审核人员配置Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "报废审核人员配置接口")
@RestController
@RequestMapping("/scrap_auditor_set")
public class ScrapAuditorSetController extends BaseController {
    @Autowired
    private IScrapAuditorSetService scrapAuditorSetService;

    /**
     * 查询报废审核人员配置列表
     */
    @ApiOperation(value = "查询报废审核人员配置列表")
    @RequiresPermissions("scrap:set:list")
    @GetMapping("/list")
    public TableDataInfo list(ScrapAuditorSet scrapAuditorSet) {
        startPage();
        List<ScrapAuditorSet> list = scrapAuditorSetService.selectScrapAuditorSetList(scrapAuditorSet);
        return getDataTable(list);
    }

    /**
     * 导出报废审核人员配置列表
     */
    @ApiOperation(value = "导出报废审核人员配置列表")
    @PreventRepeatSubmit
    @RequiresPermissions("scrap:set:export")
    @SysLog(title = "报废审核人员配置", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出报废审核人员配置")
    @PostMapping("/export")
    public void export(HttpServletResponse response, ScrapAuditorSet scrapAuditorSet) {
        List<ScrapAuditorSet> list = scrapAuditorSetService.selectScrapAuditorSetList(scrapAuditorSet);
        ExcelUtil<ScrapAuditorSet> util = new ExcelUtil<ScrapAuditorSet>(ScrapAuditorSet.class);
        util.exportExcel(response, list, "报废审核人员配置数据");
    }

    /**
     * 获取报废审核人员配置详细信息
     */
    @ApiOperation(value = "获取报废审核人员配置详细信息")
    @RequiresPermissions("scrap:set:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(scrapAuditorSetService.selectScrapAuditorSetById(id));
    }

    /**
     * 新增报废审核人员配置
     */
    @ApiOperation(value = "新增报废审核人员配置")
    @PreventRepeatSubmit
    @RequiresPermissions("scrap:set:add")
    @SysLog(title = "报废审核人员配置", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增报废审核人员配置")
    @PostMapping
    public AjaxResult add(@RequestBody ScrapAuditorSet scrapAuditorSet) {
        try {
            return toAjax(scrapAuditorSetService.insertScrapAuditorSet(scrapAuditorSet));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改报废审核人员配置
     */
    @ApiOperation(value = "修改报废审核人员配置")
    @PreventRepeatSubmit
    @RequiresPermissions("scrap:set:edit")
    @SysLog(title = "报废审核人员配置", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改报废审核人员配置")
    @PutMapping
    public AjaxResult edit(@RequestBody ScrapAuditorSet scrapAuditorSet) {
        try {
            return toAjax(scrapAuditorSetService.updateScrapAuditorSet(scrapAuditorSet));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除报废审核人员配置
     */
    @ApiOperation(value = "删除报废审核人员配置")
    @PreventRepeatSubmit
    @RequiresPermissions("scrap:set:remove")
    @SysLog(title = "报废审核人员配置", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除报废审核人员配置")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(scrapAuditorSetService.deleteScrapAuditorSetByIds(ids));
    }
}
